#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

## Instructions:

## * Add a selection for the distribution, and have the sampling system sample depending on that selection.

library(shiny)
vals <- rnorm(5000)

# Define UI for application that draws a histogram
ui <- fluidPage(
    
    # Application title
    titlePanel("Random distribution generation"),
    
    # Sidebar with a slider input for number of bins 
    sidebarLayout(
        sidebarPanel(
            sliderInput("bins",
                        "Number of bins:",
                        min = 1,
                        max = 50,
                        value = 30),
            numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
            tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
            tags$p(),
            tags$hr(),
            tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
                    href="http://mtu.edu")
        ),
        
        # Show a plot of the generated distribution
        mainPanel(
            h1("Histogram and normal q-q plot"),
            plotOutput("distPlot")
        )
    )
)

# Define server logic required to draw a histogram
server <- function(input, output) {
    
    output$distPlot <- renderPlot({
        # generate bins based on input$bins from ui.R
        x    <-  rnorm(input$number)
        bins <- seq(min(x), max(x), length.out = input$bins + 1)
        
        par(mfrow=c(1,2))
        # draw the histogram with the specified number of bins
        hist(x, breaks = bins, col = 'gold', border = 'white')
        qqplot(x,vals)
    })
}

