#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

## Instructions:

## Now that we have a reactive data element, let's make another plot and a table.  
##  * Create an output table that shows the summary statistics of your distribution
##  * Add a text output that gets set when you change the distribution, so that it says "using x distribution with a mean of x and standard devation of x"

library(shiny)

# Define UI for application that draws a histogram
ui <- fluidPage(
    
    
    # Application title
    titlePanel("Random distribution generation"),
    
    # Sidebar with a slider input for number of bins 
    sidebarLayout(
        sidebarPanel(
            sliderInput("bins",                        "Number of bins:",
                        min = 1,
                        max = 50,
                        value = 30),
            selectInput("type",label="Select form of distribution",
                        choices=c("normal","uniform")),
            numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
            
            
            tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
            tags$p(),
            tags$hr(),
            tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
                    href="http://mtu.edu")
        ),
        
        # Show a plot of the generated distribution
        mainPanel(
            h1("Histograms"),
            plotOutput("distPlot"),
            plotOutput("distPlot2",width=400, height=400)
        )
    )
)



# Define server logic required to draw a histogram
server <- function(input, output) {
    
    ##put reactive data element here:
    data <- reactive(
        {
            if( input$type=="normal")
            {
                x    <-  rnorm(input$number)  
            }else if(input$type=="uniform")
            {
                x    <-  runif(input$number)  
            }
            x
        }
    )
    
    output$distPlot <- renderPlot({
        x <- data()
        bins <- seq(min(x), max(x), length.out = input$bins + 1)
        
        par(mfrow=c(1,1))
        # draw the histogram with the specified number of bins
        hist(x, breaks = bins, col = 'gold', border = 'white')
        
    })
    
    output$distPlot2 <- renderPlot({
        x <- data()
        
        par(mfrow=c(1,1))
        # draw the histogram with the specified number of bins
        qqnorm(x)
        
    })
}

# Run the application 
shinyApp(ui = ui, server = server)
