#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

## Instructions:
## We can update and set input values with update....() functions.
## Use these so that when a uniform distribution is selected, you set the
## number of bins to 10, and when you use a normal distribution, you set it to 25.
## 
## To do this, we need to have the server function take a third argument, which
## is a variable that allows the callback to the input. You can call this with a variable name 
## server. Then, the updateNumericInput() takes server as the first argument, and you
## set the value argument to be what  you want set.


library(shiny)

# Define UI for application that draws a histogram
ui <- fluidPage(
  
  
  # Application title
  titlePanel("Random distribution generation"),
  
  # Sidebar with a slider input for number of bins 
  sidebarLayout(
    sidebarPanel(
      sliderInput("bins",                        "Number of bins:",
                  min = 1,
                  max = 50,
                  value = 30),
      selectInput("type",label="Select form of distribution",
                  choices=c("normal","uniform")),
      numericInput("number","Number of samples",500,min=100,max=10000,step=100,width='100%'),
      
      
      tags$a("Link to wikipedia",href="http://en.wikipedia.org"),
      tags$p(),
      tags$hr(),
      tags$a( tags$img(src="https://upload.wikimedia.org/wikipedia/en/c/c9/Michigan_Technological_University_logo.svg"),
              href="http://mtu.edu")
    ),
    
    # Show a plot of the generated distribution
    mainPanel(
      h1("Histograms"),
      plotOutput("distPlot"),
      plotOutput("distPlot2",width=400, height=400),
      tableOutput("table"),
      h3("Overview in text:"),
      textOutput("textdesc")
    )
  )
)



# Define server logic required to draw a histogram
server <- function(input, output) {
  
  ##put reactive data element here:
  data <- reactive(
    {
      if( input$type=="normal")
      {
        x    <-  rnorm(input$number)  
      }else if(input$type=="uniform")
      {
        x    <-  runif(input$number)  
      }
      x
    }
  )
  
  output$distPlot <- renderPlot({
    x <- data()
    bins <- seq(min(x), max(x), length.out = input$bins + 1)
    
    par(mfrow=c(1,1))
    # draw the histogram with the specified number of bins
    hist(x, breaks = bins, col = 'gold', border = 'white')
    
  })
  
  output$distPlot2 <- renderPlot({
    x <- data()
    
    par(mfrow=c(1,1))
    # draw the histogram with the specified number of bins
    qqnorm(x)
    
  })
  
  output$table<- renderTable({
    x <- data()
    summary(data.frame(x))
  })
  
  output$textdesc <- renderText(
    paste("using ",input$type," distribution with a mean of ", round(mean(data()),3),
          " and standard devation of",round(sd(data()),3),"\n")
  )
  
}

# Run the application 
shinyApp(ui = ui, server = server)
